@@ -1,4 +1,4 @@
-# $Id: Kex.pm,v 1.23 2009/01/26 01:00:25 turnstep Exp $
+# $Id: Kex.pm,v 1.16 2001/04/20 23:40:17 btrott Exp $
 
 package Net::SSH::Perl::Kex;
 use strict;
@@ -18,7 +18,6 @@ use Net::SSH::Perl::Constants qw(
 
 use Carp qw( croak );
 use Digest::SHA1 qw( sha1 );
-use Scalar::Util qw(weaken);
 
 use vars qw( @PROPOSAL );
 @PROPOSAL = (
@@ -37,9 +36,7 @@ use vars qw( @PROPOSAL );
 sub new {
     my $class = shift;
     my $ssh = shift;
-    my $kex = bless { ssh => $ssh }, $class;
-    weaken $kex->{ssh};
-    $kex;
+    bless { ssh => $ssh }, $class;
 }
 
 sub client_kexinit { $_[0]->{client_kexinit} }
@@ -56,7 +53,7 @@ sub receive_comp   { $_[0]->{comp}[0] }
 sub exchange {
     my $kex = shift;
     my $ssh = $kex->{ssh};
-    my $packet = shift;
+    my $packet;
 
     my @proposal = @PROPOSAL;
     if (!$ssh->config->get('ciphers')) {
@@ -65,12 +62,6 @@ sub exchange {
         }
     }
     if (my $cs = $ssh->config->get('ciphers')) {
-        # SSH2 cipher names are different; for compatibility, we'll map
-        # valid SSH1 ciphers to the SSH2 equivalent names
-        if($ssh->protocol eq PROTOCOL_SSH2) {
-            my %ssh2_cipher = reverse %Net::SSH::Perl::Cipher::CIPHERS_SSH2;
-            $cs = join ',', map $ssh2_cipher{$_} || $_, split(/,/, $cs);
-        }
         $proposal[ PROPOSAL_CIPH_ALGS_CTOS ] =
         $proposal[ PROPOSAL_CIPH_ALGS_STOC ] = $cs;
     }
@@ -82,13 +73,9 @@ sub exchange {
         $proposal[ PROPOSAL_COMP_ALGS_CTOS ] =
         $proposal[ PROPOSAL_COMP_ALGS_STOC ] = "none";
     }
-    if ($ssh->config->get('host_key_algorithms')) {
-        $proposal[ PROPOSAL_SERVER_HOST_KEY_ALGS ] =
-            $ssh->config->get('host_key_algorithms');
-    }
 
     $kex->{client_kexinit} = $kex->kexinit(\@proposal);
-    my($sprop) = $kex->exchange_kexinit($packet);
+    my($sprop) = $kex->exchange_kexinit;
 
     $kex->choose_conf(\@proposal, $sprop);
     $ssh->debug("Algorithms, c->s: " .
@@ -102,14 +89,16 @@ sub exchange {
     $ssh->debug("Waiting for NEWKEYS message.");
     $packet = Net::SSH::Perl::Packet->read_expect($ssh, SSH2_MSG_NEWKEYS);
 
-    $ssh->debug("Send NEWKEYS.");
+    $ssh->debug("Enabling incoming encryption/MAC/compression.");
+    for my $att (qw( mac ciph comp )) {
+        $kex->{$att}[0]->enable if $kex->{$att}[0];
+    }
+
+    $ssh->debug("Send NEWKEYS, enable outgoing encryption/MAC/compression.");
     $packet = $ssh->packet_start(SSH2_MSG_NEWKEYS);
     $packet->send;
 
-    $ssh->debug("Enabling encryption/MAC/compression.");
-    $ssh->{kex} = $kex;
     for my $att (qw( mac ciph comp )) {
-        $kex->{$att}[0]->enable if $kex->{$att}[0];
         $kex->{$att}[1]->enable if $kex->{$att}[1];
     }
 }
@@ -118,7 +107,7 @@ sub kexinit {
     my $kex = shift;
     my($proposal) = @_;
 
-    my $b = Net::SSH::Perl::Buffer->new( MP => 'SSH2' );
+    my $b = Net::SSH::Perl::Buffer->new;
     my $cookie = join '', map chr rand 255, 1..16;
     $b->put_chars($cookie);
     $b->put_str($_) for @$proposal;
@@ -130,21 +119,14 @@ sub kexinit {
 sub exchange_kexinit {
     my $kex = shift;
     my $ssh = $kex->{ssh};
-    my $received_packet = shift;
     my $packet;
 
     $packet = $ssh->packet_start(SSH2_MSG_KEXINIT);
     $packet->put_chars($kex->client_kexinit->bytes);
     $packet->send;
 
-    if ( defined $received_packet ) {
-	$ssh->debug("Received key-exchange init (KEXINIT), sent response.");
-	$packet = $received_packet;
-    }
-    else {
-	$ssh->debug("Sent key-exchange init (KEXINIT), wait response.");
-	$packet = Net::SSH::Perl::Packet->read_expect($ssh, SSH2_MSG_KEXINIT);
-    }
+    $ssh->debug("Sent key-exchange init (KEXINIT), wait response.");
+    $packet = Net::SSH::Perl::Packet->read_expect($ssh, SSH2_MSG_KEXINIT);
     $kex->{server_kexinit} = $packet->data;
 
     $packet->get_char for 1..16;
@@ -157,11 +139,11 @@ sub exchange_kexinit {
 
 sub derive_keys {
     my $kex = shift;
-    my($hash, $shared_secret, $session_id) = @_;
+    my($hash, $shared_secret) = @_;
     my @keys;
     for my $i (0..5) {
-        push @keys, derive_key(ord('A')+$i, $kex->{we_need}, $hash,
-			       $shared_secret, $session_id);
+        push @keys,
+            derive_key(ord('A')+$i, $kex->{we_need}, $hash, $shared_secret);
     }
     my $is_ssh2 = $kex->{ssh}->protocol == PROTOCOL_SSH2;
     for my $mode (0, 1) {
@@ -174,10 +156,10 @@ sub derive_keys {
 }
 
 sub derive_key {
-    my($id, $need, $hash, $shared_secret, $session_id) = @_;
-    my $b = Net::SSH::Perl::Buffer->new( MP => 'SSH2' );
+    my($id, $need, $hash, $shared_secret) = @_;
+    my $b = Net::SSH::Perl::Buffer->new;
     $b->put_mp_int($shared_secret);
-    my $digest = sha1($b->bytes, $hash, chr($id), $session_id);
+    my $digest = sha1($b->bytes, $hash, chr($id), $hash);
     for (my $have = 20; $need > $have; $have += 20) {
         $digest .= sha1($b->bytes, $hash, $digest);
     }
